@@ -27,6 +27,7 @@ import davmail.exchange.ExchangeSession;
 import davmail.exchange.ExchangeSessionFactory;
 import davmail.exchange.ICSBufferedReader;
 import davmail.exchange.XMLStreamUtil;
+import davmail.exchange.dav.DavExchangeSession;
 import davmail.ui.tray.DavGatewayTray;
 import davmail.util.IOUtil;
 import davmail.util.StringUtil;
@@ -760,6 +761,8 @@ public class CaldavConnection extends AbstractConnection {
                         }
                         if (!eventName.equals(item.getName())) {
                             DavGatewayTray.warn(new BundleMessage("LOG_MESSAGE", "wrong item name requested "+eventName+" received "+item.getName()));
+                            // force item name to requested value
+                            item.setItemName(eventName);
                         }
                         appendItemResponse(response, request, item);
                     }
@@ -1248,7 +1251,15 @@ public class CaldavConnection extends AbstractConnection {
         sendClient("HTTP/1.1 " + status + ' ' + HttpStatus.getStatusText(status));
         if (status != HttpStatus.SC_UNAUTHORIZED) {
             sendClient("Server: DavMail Gateway " + DavGateway.getCurrentVersion());
-            sendClient("DAV: 1, calendar-access, calendar-auto-schedule, calendarserver-private-events, addressbook");
+            String scheduleMode;
+            // enable automatic scheduling over EWS, can be disabled
+            if (Settings.getBooleanProperty("davmail.caldavAutoSchedule", true)
+                    && !(session instanceof DavExchangeSession)) {
+                scheduleMode = "calendar-auto-schedule";
+            } else {
+                scheduleMode = "calendar-schedule";
+            }
+            sendClient("DAV: 1, calendar-access, "+scheduleMode+", calendarserver-private-events, addressbook");
             SimpleDateFormat formatter = new SimpleDateFormat("EEE, dd MMM yyyy HH:mm:ss Z", Locale.ENGLISH);
             // force GMT timezone
             formatter.setTimeZone(ExchangeSession.GMT_TIMEZONE);
