@@ -218,7 +218,9 @@ public final class Field {
         FIELD_MAP.put("ismeeting", new UnindexedFieldURI("calendar:IsMeeting"));
         FIELD_MAP.put("apptstateflags", new ExtendedFieldURI(ExtendedFieldURI.DistinguishedPropertySetType.Appointment, 0x8217, ExtendedFieldURI.PropertyType.Integer)); // PidLidAppointmentStateFlags 1: Meeting, 2: Received, 4: Cancelled
         FIELD_MAP.put("appointmentstate", new UnindexedFieldURI("calendar:AppointmentState"));
-        FIELD_MAP.put("myresponsetype", new UnindexedFieldURI("calendar:MyResponseType"));
+        // isorganizer is Exchange 2013 and later only
+        //FIELD_MAP.put("isorganizer", new UnindexedFieldURI("calendar:IsOrganizer"));
+
         FIELD_MAP.put("calendaruid", new ExtendedFieldURI(ExtendedFieldURI.DistinguishedPropertySetType.PublicStrings, "urn:schemas:calendar:uid", ExtendedFieldURI.PropertyType.String));
 
         FIELD_MAP.put("meetingtimezone", new UnindexedFieldURI("calendar:MeetingTimeZone"));
