@@ -59,6 +59,7 @@ public class SettingsFrame extends JFrame {
     protected JTextField keepDelayField;
     protected JTextField sentKeepDelayField;
     protected JTextField caldavPastDelayField;
+    protected JCheckBox caldavAutoScheduleCheckBox;
     protected JTextField imapIdleDelayField;
 
     protected JCheckBox useSystemProxiesField;
@@ -277,18 +278,24 @@ public class SettingsFrame extends JFrame {
         httpProxyPortField.setEnabled(enableProxy);
         httpProxyUserField.setEnabled(enableProxy || useSystemProxies);
         httpProxyPasswordField.setEnabled(enableProxy || useSystemProxies);
-        noProxyForField.setEnabled(enableProxy || useSystemProxies);
+        noProxyForField.setEnabled(enableProxy);
 
         useSystemProxiesField.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent evt) {
                 boolean newUseSystemProxies = useSystemProxiesField.isSelected();
-                boolean newEnableProxy = enableProxyField.isSelected();
-                enableProxyField.setEnabled(!newUseSystemProxies);
-                httpProxyField.setEnabled(!newUseSystemProxies && newEnableProxy);
-                httpProxyPortField.setEnabled(!newUseSystemProxies && newEnableProxy);
-                httpProxyUserField.setEnabled(newUseSystemProxies || newEnableProxy);
-                httpProxyPasswordField.setEnabled(newUseSystemProxies || newEnableProxy);
-                noProxyForField.setEnabled(newUseSystemProxies || newEnableProxy);
+                if (newUseSystemProxies) {
+                    enableProxyField.setSelected(false);
+                    enableProxyField.setEnabled(false);
+                    httpProxyField.setEnabled(false);
+                    httpProxyPortField.setEnabled(false);
+                    httpProxyUserField.setEnabled(true);
+                    httpProxyPasswordField.setEnabled(true);
+                    noProxyForField.setEnabled(false);
+                } else {
+                    enableProxyField.setEnabled(true);
+                    httpProxyUserField.setEnabled(false);
+                    httpProxyPasswordField.setEnabled(false);
+                }
             }
         });
         enableProxyField.addActionListener(new ActionListener() {
@@ -432,7 +439,7 @@ public class SettingsFrame extends JFrame {
     }
 
     protected JPanel getOtherSettingsPanel() {
-        JPanel otherSettingsPanel = new JPanel(new GridLayout(14, 2));
+        JPanel otherSettingsPanel = new JPanel(new GridLayout(15, 2));
         otherSettingsPanel.setBorder(BorderFactory.createTitledBorder(BundleMessage.format("UI_OTHER")));
 
         folderSizeLimitField = new JTextField(Settings.getProperty("davmail.folderSizeLimit"), 6);
@@ -460,6 +467,8 @@ public class SettingsFrame extends JFrame {
         smtpSaveInSentCheckBox.setSelected(Settings.getBooleanProperty("davmail.smtpSaveInSent", true));
         disableUpdateCheck = new JCheckBox();
         disableUpdateCheck.setSelected(Settings.getBooleanProperty("davmail.disableUpdateCheck"));
+        caldavAutoScheduleCheckBox = new JCheckBox();
+        caldavAutoScheduleCheckBox.setSelected(Settings.getBooleanProperty("davmail.caldavAutoSchedule"));
 
         addSettingComponent(otherSettingsPanel, BundleMessage.format("UI_FOLDER_SIZE_LIMIT"), folderSizeLimitField,
                 BundleMessage.format("UI_FOLDER_SIZE_LIMIT_HELP"));
@@ -490,6 +499,9 @@ public class SettingsFrame extends JFrame {
         addSettingComponent(otherSettingsPanel, BundleMessage.format("UI_DISABLE_UPDATE_CHECK"), disableUpdateCheck,
                 BundleMessage.format("UI_DISABLE_UPDATE_CHECK_HELP"));
 
+        addSettingComponent(otherSettingsPanel, BundleMessage.format("UI_CALDAV_AUTO_SCHEDULE"), caldavAutoScheduleCheckBox,
+                BundleMessage.format("UI_CALDAV_AUTO_SCHEDULE_HELP"));
+
         updateMaximumSize(otherSettingsPanel);
         return otherSettingsPanel;
     }
@@ -594,11 +606,11 @@ public class SettingsFrame extends JFrame {
         boolean enableProxy = Settings.getBooleanProperty("davmail.enableProxy");
         enableProxyField.setSelected(enableProxy);
         enableProxyField.setEnabled(!useSystemProxies);
-        httpProxyField.setEnabled(!useSystemProxies && enableProxy);
-        httpProxyPortField.setEnabled(!useSystemProxies && enableProxy);
+        httpProxyField.setEnabled(enableProxy);
+        httpProxyPortField.setEnabled(enableProxy);
         httpProxyUserField.setEnabled(useSystemProxies || enableProxy);
         httpProxyPasswordField.setEnabled(useSystemProxies || enableProxy);
-        noProxyForField.setEnabled(useSystemProxies || enableProxy);
+        noProxyForField.setEnabled(enableProxy);
         httpProxyField.setText(Settings.getProperty("davmail.proxyHost"));
         httpProxyPortField.setText(Settings.getProperty("davmail.proxyPort"));
         httpProxyUserField.setText(Settings.getProperty("davmail.proxyUser"));
@@ -620,7 +632,7 @@ public class SettingsFrame extends JFrame {
         imapAutoExpungeCheckBox.setSelected(Settings.getBooleanProperty("davmail.imapAutoExpunge", true));
         imapAlwaysApproxMsgSizeCheckBox.setSelected(Settings.getBooleanProperty("davmail.imapAlwaysApproxMsgSize", false));
         enableKeepAliveCheckBox.setSelected(Settings.getBooleanProperty("davmail.enableKeepAlive", false));
-        popMarkReadOnRetrCheckBox.setSelected(Settings.getBooleanProperty("davmail.popMarkReadOnRetrCheckBox", false));
+        popMarkReadOnRetrCheckBox.setSelected(Settings.getBooleanProperty("davmail.popMarkReadOnRetr", false));
         setEwsModeSelectedItem(Settings.getProperty("davmail.enableEws", "auto"));
         smtpSaveInSentCheckBox.setSelected(Settings.getBooleanProperty("davmail.smtpSaveInSent", true));
         enableKerberosCheckBox.setSelected(Settings.getBooleanProperty("davmail.enableKerberos", false));
@@ -663,7 +675,7 @@ public class SettingsFrame extends JFrame {
         setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
         setTitle(BundleMessage.format("UI_DAVMAIL_SETTINGS"));
         try {
-            setIconImage(DavGatewayTray.getFrameIcon());
+            setIconImages(DavGatewayTray.getFrameIcons());
         } catch (NoSuchMethodError error) {
             DavGatewayTray.debug(new BundleMessage("LOG_UNABLE_TO_SET_ICON_IMAGE"));
         }
@@ -774,6 +786,7 @@ public class SettingsFrame extends JFrame {
                 Settings.setProperty("davmail.allowRemote", String.valueOf(allowRemoteField.isSelected()));
                 Settings.setProperty("davmail.server.certificate.hash", certHashField.getText());
                 Settings.setProperty("davmail.disableUpdateCheck", String.valueOf(disableUpdateCheck.isSelected()));
+                Settings.setProperty("davmail.caldavAutoSchedule", String.valueOf(caldavAutoScheduleCheckBox.isSelected()));
 
                 Settings.setProperty("davmail.caldavEditNotifications", String.valueOf(caldavEditNotificationsField.isSelected()));
                 Settings.setProperty("davmail.caldavAlarmSound", String.valueOf(caldavAlarmSoundField.getText()));
